@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::StaticInstall; # git description: v0.008-8-gdac440b
+package Dist::Zilla::Plugin::StaticInstall; # git description: v0.009-6-g2a0e443
 # ABSTRACT: (EXPERIMENTAL, DANGEROUS) Identify a distribution as eligible for static installation
 # KEYWORDS: distribution metadata toolchain static dynamic installation
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.009';
+our $VERSION = '0.010';
 
 use Moose;
 with 'Dist::Zilla::Role::MetaProvider',
@@ -194,7 +194,7 @@ sub _heuristics
     $self->$log('checking META.json');
     my $metajson = first { blessed($_) eq 'Dist::Zilla::Plugin::MetaJSON' } @{ $self->zilla->plugins };
     return (0, 'META.json is not being added to the distribution') if not $metajson;
-    return (0, [ 'META.json is using meta-spec version %s', $metajson->version ]) if $metajson->version ne '2';
+    return (0, [ 'META.json is using meta-spec version %s', $metajson->version ]) if $metajson->version < '2';
 
     my @filenames = map { $_->name } @{ $self->zilla->files };
 
@@ -232,7 +232,7 @@ Dist::Zilla::Plugin::StaticInstall - (EXPERIMENTAL, DANGEROUS) Identify a distri
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
@@ -398,7 +398,7 @@ There is also a mailing list available for users of this distribution, at
 L<http://dzil.org/#mailing-list>.
 
 There is also an irc channel available for users of this distribution, at
-L<irc://irc.perl.org/#distzilla>.
+L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
 
 I am also usually active on irc, as 'ether' at C<irc.perl.org>.
 
